<?php
/**
 * Answer Page
 *
 * This page will take output from the page question.php.  It will take the
 * answer given by that page, and test it in the question that was presented.
 * It will then update the user's score and present the results to the user.
 * It will not allow the user to see this page unless he/she has already selected
 * a quest and has viewed a question.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * Every page must load the session so that everything works correctly
 */
include ('includes/session.php');

// Make sure that the user has a quest set up
if (!in_array($_SESSION['quest'], array('angelology', 'anthropology', 'hamartiology', 'inquisition'))) {
	header("Location: start.php");
	$_SESSION['feedback'] = '<p class="warn">You must start a Quest to answer a Trial.</p>';
	exit();
} // end sending them to start if they have no quest

if (!is_numeric($_POST['answer'])) {
	header("Location: question.php");
	$_SESSION['feedback'] = '<p class="warn">You must answer a Trial before you can progress.</p>';
	exit();
} // end sending them to question if they have no answer

// Make sure that the question has not been answered already
if ($_SESSION['question']->getIsCorrect() !== NULL) {
	header("Location: question.php");
	$_SESSION['feedback'] = '<p class="warn">You have already answered that Trial.  You must move on.</p>';
	exit();
} // end check that the question hasn't already been answered

//If the user is in the inquisition and they have not explained themselves, send them back
if (isset($_POST['why']) and $_POST['why'] == '') {
	header("Location: question.php");
	$_SESSION['feedback'] = '<p class="warn">You must explain your answer!</p>';
	exit();
} // end check for the why answer

// Modify their score based on how they answered
$correct = $_SESSION['question']->answerQuestion($_POST['answer']);
$points = 0;
switch ($_SESSION['question']->getDifficulty()) {
	case 0:
		$points = 1;
		break;
	case 1:
		$points = 5;
		break;
	case 2:
		$points = 10;
		break;
} // end determine the points
if (!$correct) $points = $points * -1;
$_SESSION['player']->addToScore($points);

// Add the quest title
$content = '<p id="title"><img src="';
switch ($_SESSION['quest']) {
	case 'angelology':
		$content .= 'images/title_angelology.jpg';
		break;
	case 'anthropology':
		$content .= 'images/title_antropo.jpg';
		break;
	case 'hamartiology':
		$content .= 'images/title_sin.jpg';
		break;
	case 'inquisition':
		$content .= 'images/title_inquisition.jpg';
		break;
} // end addition of the correct title
$content .= "\" /></p>\r\n";

// Add some content
$content .= '<table cellpadding="0" cellspacing="0" id="layout_page">
	<tr>
		<td id="layout_graphic">
			<img src="' . $_SESSION['question']->getImage() . '" alt="Question Image" border="0" />
		</td>
		<td id="layout_question">
			' . $_SESSION['question']->getQuestion() . '
				<fieldset>
					<legend>Answers</legend>' . "\r\n";
// Let them know how they answered
if ($correct) {
	$content .= '<p class="alert">You have answered wisely; and have gained ' . $points . ' points.</p>';
} // end addition of correct alert
else {
	$content .= '<p class="warn">You have answered foolishly; and have lost ' . ($points * -1) . ' points.</p>';
}
//Output the answers
foreach ($_SESSION['question']->getAnswers() as $key=>$answer) {
	$content .= "\t\t\t\t" . '<div';
	if ($answer['is_correct']) $content .= ' class="correct" ';
	else $content .= ' class="incorrect" ';
	if ($key == $_POST['answer']) $content .= ' id="selected" ';
	$content .= '>' . $answer['answer'] . '</div>' . "\r\n";
} // end adding each answer
$content .= "\t\t\t\t</fieldset>\r\n";
// Find the number of incorrect answers they have given for this quest
$incorrect = $_SESSION[$_SESSION['quest']]->getIncorrect();
// If they have 5 or less incorrect answers, let them continue
if ($incorrect <= 5) {
	// See if the quest is complete.  If not, tell them what is next
	if (!$_SESSION[$_SESSION['quest']]->getIsComplete()) {
		$content .= "\t\t\t" . '<p>You may only fail 5 trials in a quest, and you have failed ' . $incorrect . ' so far.  You may continue to your next trial.
			<br /><a href="question.php">Continue to the next Trial</a></p>' . "\r\n";
	} // end actions if their quest is not complete
	else {
		$content .= "\t\t\t" . '<p>You have successfully completed this quest!  <a href="quest_complete.php">You may now receive your reward.</a></p>';
	} // end actions if their quest is complete
} // end check for the incorrect
else {
	$content .= "\t\t\t" . '<p>You have failed more than 5 trials in this quest.  You must now restart your quest.
			<br /><a href="start.php">Start this or another Quest</a></p>' . "\r\n";
	// reset this list of questions
	$_SESSION[$_SESSION['quest']]->loadType($_SESSION['quest']);
} // end actions if they must reset their quest
$content .= "\t\t" . '</td>
	</tr>
	<tr>
		<td id="layout_score">
			' . $_SESSION['player']->toScore() . '
			<img src="' . $_SESSION['player']->getAvatar() . '" alt="" border="0" /><br />
			' . $_SESSION['player']->getName() . '
		</td>
		<td id="layout_map">
			<img src="images/';
// Add logic for the output of the correct map
$content .= 'map_' . $_SESSION['quest'] . '_';
// Determine their percentage done
$answered = $_SESSION[$_SESSION['quest']]->percentAnswered();
if ($answered < 33) $content .= '1';
elseif ($answered < 67) $content .= '2';
else $content .= '3';
$content .= '.jpg" alt="World Map" border="0" />
		</td>
	</tr>
</table>';

// Add the content to the page
$_SCRIPT['page']->setContent($content);
// Output the page
$_SCRIPT['page']->outputPage();
