<?php
/**
 * XhtmlPage Class Definition Page
 *
 * This file contains the definition for the XhtmlPage class.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * XhtmlPage Class Definition
 *
 * This class will output any page on the site.  All content will be run through
 * this class, which will then add the correct headers, footers, and other info
 * needed for a proper XHTML page to be output.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 */
class XhtmlPage {
	/************************************************************************
								Properties
	************************************************************************/
	/**
	 * HTML for the head of the document
	 * @var string
	 */
	protected $header;
	
	/**
	 * Title of the page
	 * @var string
	 */
	protected $title;
	
	/**
	 * Footer of the page
	 * @var string
	 */
	protected $footer;
	
	/**
	 * Content of the page
	 * @var string
	 */
	protected $content;
	
	/**
	 * Relative path to the stylesheet used for this page
	 * @var string
	 */
	protected $stylesheet;
	
	/************************************************************************
								Methods
	************************************************************************/
	/**
	 * Creation of this page
	 *
	 * This method will give the basic structure to this object.
	 * @param string $title
	 * @param string $content
	 * @param string $stylesheet
	 * @return void
	 */
	public function __construct($content = '', $title = "The Theologian", $stylesheet = 'css/theologian.css') {
		// Set each parameter into the stylesheet
		$this->setContent($content);
		$this->setTitle($title);
		$this->setStylesheet($stylesheet);
		// Create the basic headers and footers
		$this->setHeader('<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
        "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><theologian_title /></title>
	<link rel="stylesheet" href="<theologian_stylesheet />" media="all" />
</head>
<body>' . "\r\n");
		$this->setFooter('<p id="footer"><a href="top_theologians.php">Roles of the Order of Holsteen</a> /\ <a href="reset.php">Reset Game</a> \/ <a href="contributors.php">Contributors</a>
	<br /><!--Creative Commons License--><a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/"><img alt="Creative Commons License" style="border-width: 0" src="http://i.creativecommons.org/l/by-sa/2.5/88x31.png"/></a><!--<br/>This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/">Creative Commons Attribution-Share Alike 2.5  License</a>.--><!--/Creative Commons License--><!-- <rdf:RDF xmlns="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#">
	<Work rdf:about="">
		<license rdf:resource="http://creativecommons.org/licenses/by-sa/2.5/" />
	<dc:type rdf:resource="http://purl.org/dc/dcmitype/InteractiveResource" />
	</Work>
	<License rdf:about="http://creativecommons.org/licenses/by-sa/2.5/"><permits rdf:resource="http://web.resource.org/cc/Reproduction"/><permits rdf:resource="http://web.resource.org/cc/Distribution"/><requires rdf:resource="http://web.resource.org/cc/Notice"/><requires rdf:resource="http://web.resource.org/cc/Attribution"/><permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/><requires rdf:resource="http://web.resource.org/cc/ShareAlike"/></License></rdf:RDF> -->
</p></body>
</html>
');
	} // end fuction __construct
	
	/************************************************************************
							Setter and Getters
	************************************************************************/
	/**
	 * Set a value into the header method
	 * @param string $string
	 * @return bool
	 */
	public function setHeader($string) {
		// Make sure that it's a string
		$string = (string) $string;
		$this->header = $string;
		return true;
	} // end function setHeader()
	
	/**
	 * Get the header 
	 * @return string
	 */
	public function getHeader() {
		return $this->header;
	} // end function getHeader()
	
	/**
	 * Set a value into the title property
	 * @param string $string
	 * @return bool
	 */
	public function setTitle($string) {
		// Make sure that it's a string
		$string = (string) $string;
		$this->title = $string;
		return true;
	} // end function setTitle()
	
	/**
	 * Get the title 
	 * @return string
	 */
	public function getTitle() {
		return $this->title;
	} // end function getTitle()
	
	/**
	 * Set a value into the footer property
	 * @param string $string
	 * @return bool
	 */
	public function setFooter($string) {
		// Make sure that it's a string
		$string = (string) $string;
		$this->footer = $string;
		return true;
	} // end function setFooter()
	
	/**
	 * Get the title 
	 * @return string
	 */
	public function getFooter() {
		return $this->footer;
	} // end function getFooter()
	
	/**
	 * Set a value into the content property
	 * @param string $string
	 * @return bool
	 */
	public function setContent($string) {
		// Make sure that it's a string
		$string = (string) $string;
		$this->content = $string;
		return true;
	} // end function setContent()
	
	/**
	 * Get the title 
	 * @return string
	 */
	public function getContent() {
		return $this->content;
	} // end function getContent()
	
	/**
	 * Set a value into the stylesheet property
	 * @param string $string
	 * @return bool
	 */
	public function setStylesheet($string) {
		// Make sure that it's a string
		$string = (string) $string;
		$this->stylesheet = $string;
		return true;
	} // end function setStylesheet()
	
	/**
	 * Get the title 
	 * @return string
	 */
	public function getStylesheet() {
		return $this->stylesheet;
	} // end function getStylesheet()
	
	/**
	 * Output the page as it currently exists
	 * @return void
	 */
	public function outputPage() {
		echo str_replace('<theologian_stylesheet />', $this->getStylesheet(), str_replace('<theologian_title />', $this->getTitle(), $this->getHeader()));
		if (isset($_SESSION['feedback'])) echo $_SESSION['feedback'];
		unset($_SESSION['feedback']);
		echo $this->getContent();
		echo "\r\n";
		echo $this->getFooter();
	} // end function outputPage()
	
} // end creation of XhtmlPage