<?php
/**
 * Final Page of the Site
 *
 * This is the last page that a user sees when playing the game.  It will make
 * sure that the user has gone through all of the 4 quests.  It will then enter
 * the user's score into the database for later retrieval.  It will then show 
 * the funny graphic of Dr. Holsteen.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * Every page must load the session so that everything works correctly
 */
include ('includes/session.php');

// Make sure that the player has actually finished all of the questions
if (!$_SESSION['angelology']->getIsComplete() ||
	!$_SESSION['anthropology']->getIsComplete() || 
	!$_SESSION['hamartiology']->getIsComplete() ||
	!$_SESSION['inquisition']->getIsComplete()) {
	
	header("Location: start.php");
	$_SESSION['feedback'] = '<p class="warn">You must face all the trials before resting from your quest.</p>';
	exit();
} // end check that everything is actually complete

// Add This score to the scores result
$sql = "INSERT INTO scores (name, score, avatar)
		VALUES ('" . pg_escape_string($_SESSION['player']->getName()) . "', 
				'" . pg_escape_string($_SESSION['player']->getScore()) . "',
				'" . pg_escape_string($_SESSION['player']->getAvatar()) . "')";
$insert = pg_query($_SCRIPT['database'], $sql);

// Add some content
$content = "<h1>You are now The Theologian!</h1>
<h2>Use Your Power Wisely</h2>
<p>Congratulations!  You have passed all of the trials necessary to have your
	name added to the Roles of the Holsteen.  If you are one of the elite, your
	name will appear on the Roles of Holsteen for all to see.</p>
<p>Now, go forth into the world!  Speak wisly and humbly with others about
	your theology.  Make them laugh and make them think.  You are now a
	theologian!</p>
<p id='title'>
	<img src=\"images/finish_holstininanos.jpg\" alt=\"The Theologian Victorious\" border=\"0\" />
</p>";

// Reset the player, so he won't reload and add another score
	// Create the Player 
	$_SESSION['player'] = new Player;
	
	// Create the Question Lists for this session
	$_SESSION['angelology'] = new QuestionList('angelology');
	$_SESSION['anthropology'] = new QuestionList('anthropology');
	$_SESSION['hamartiology'] = new QuestionList('hamartiology');
	$_SESSION['inquisition'] = new QuestionList('inquisition');

// Add the content to the page
$_SCRIPT['page']->setContent($content);
// Output the page
$_SCRIPT['page']->outputPage();
