<?php
/**
 * Session initiation page
 *
 * This file is meant to be included on every page of the game.  It will load
 * all of the necessary classes for the objects in the game, initiate the user's
 * session, connect to the database, and make sure that all question lists have
 * been created successfully.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

// Because this is a small app, I'll just include all of the classes here
include('classes/XhtmlPage.class.php');
include('classes/Player.class.php');
include('classes/Question.class.php');
include('classes/QuestionList.class.php');

// Start by making sure that the session has been started
session_start();

// Create the script-wide database connection
$_SCRIPT['database'] = pg_connect("dbname=static_theologian user=webs");

// Create the script-wide page which will be output
$_SCRIPT['page'] = new XhtmlPage;

// If this session has not been initiated, set the basic needed variables
if (!isset($_SESSION['player']) ||
	!isset($_SESSION['angelology']) ||
	!isset($_SESSION['anthropology']) || 
	!isset($_SESSION['hamartiology']) || 
	!isset($_SESSION['inquisition'])) {
	
	// Create the Player 
	$_SESSION['player'] = new Player;
	
	// Create the Question Lists for this session
	$_SESSION['angelology'] = new QuestionList('angelology');
	$_SESSION['anthropology'] = new QuestionList('anthropology');
	$_SESSION['hamartiology'] = new QuestionList('hamartiology');
	$_SESSION['inquisition'] = new QuestionList('inquisition');
	
	// Find all of the scenarios
	$sql = "SELECT id, scenario
			FROM scenarios";
	$select = pg_query($_SCRIPT['database'], $sql);
	$_SESSION['scenarios'] = array();
	$count = pg_num_rows($select);
	for($iterate = 0; $iterate < $count; $iterate++) {
		$row = pg_fetch_array($select, $iterate, PGSQL_ASSOC);
		$_SESSION['scenarios'][$row['id']] = $row['scenario'];
	} // end walk through the scenarios
	
} // end setting up a new session