<?php
/**
 * Completed Quest Page
 *
 * After the player has completed all the questions in a quest, they are sent 
 * to this page.  They are given a message of congratulation, and this quest
 * is added to their list of completed quests.  They are then given options
 * for their remaining quests.  If they have completed all four quests, they 
 * are then forwarded on to the end page, end.php.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * Every page must load the session so that everything works correctly
 */
include ('includes/session.php');

// Make sure that they have actually completed the quest that they say that they have
if (!$_SESSION[$_SESSION['quest']]->getIsComplete()) {
	header("Location: question.php");
	$_SESSION['feedback'] = '<p class="warn">You have not yet completed your Quest, so you cannot yet gain your reward!</p>';
	exit();
} // end actions if they have not actually completed their quest

// Mark their quest as complete
$_SESSION['player']->completeQuest($_SESSION['quest']);

// If they have finished the inquisition, send them to the final page
if ($_SESSION['quest'] == 'inquisition') {
	header("Location: end.php");
	exit();
} // end sending them to final page for inquisition

// Add the quest title
$content = '<p id="title"><img src="';
switch ($_SESSION['quest']) {
	case 'angelology':
		$content .= 'images/title_angelology.jpg';
		break;
	case 'anthropology':
		$content .= 'images/title_antropo.jpg';
		break;
	case 'hamartiology':
		$content .= 'images/title_sin.jpg';
		break;
	case 'inquisition':
		$content .= 'images/title_inquisition.jpg';
		break;
} // end addition of the correct title
$content .= "\" /></p>\r\n";

// Add some content
$content .= '<table cellpadding="0" cellspacing="0" id="layout_page">
	<tr>
		<td id="layout_graphic">
			<img src="images/master_theologian.jpg" alt="The Master Theologian" border="0" />
		</td>
		<td id="layout_question">
			<p>Congratulations!  You have completed your quest of 
				' . ucwords($_SESSION['quest']) . '.  I now bestow upon you this
				metal to prove that you have completed all of my trials.  Your
				path is not yet complete, through.  You must now choose from
				one of your quests that remain below:</p>
			<form action="start_process.php" method="post" name="start">
				<fieldset>
					<legend>Quests</legend>
					<div>
						<input type="radio" name="quest" id="quest_angelology" value="angelology" ';
if ($_SESSION['player']->metals['angelology']) $content .= " disabled='disabled' ";
$content .= '/>
						<label for="quest_angelology">Angelology</label>
					</div>
					<div>
						<input type="radio" name="quest" id="quest_anthropology" value="anthropology" ';
if ($_SESSION['player']->metals['anthropology']) $content .= " disabled='disabled' ";
$content .= '/>
						<label for="quest_anthropology">Anthropology</label>
					</div>
					<div>
						<input type="radio" name="quest" id="quest_hamartiology" value="hamartiology" ';
if ($_SESSION['player']->metals['hamartiology']) $content .= " disabled='disabled' ";
$content .= '/>
						<label for="quest_hamartiology">Harmartiology</label>
					</div>';
if ($_SESSION['player']->metals['angelology'] &&
	$_SESSION['player']->metals['anthropology'] &&
	$_SESSION['player']->metals['hamartiology']) {
	$content .= "\t\t\t\t\t". '<div>
						<input type="radio" name="quest" id="quest_inquisition" value="inquisition" />
						<label for="quest_inquisition">Inquisition</label>
					</div>' . "\r\n";
} // end addition of inquisition, if it's time
$content .= "\t\t\t\t\t" . '<div>
						<input type="submit" name="submit" id="submit" value="Start Your Quest" />
					</div>
				</fieldset>
			</form>
		</td>
	</tr>
	<tr>
		<td id="layout_score">
			' . $_SESSION['player']->toScore() . '
			<img src="' . $_SESSION['player']->getAvatar() . '" alt="" border="0" /><br />
			' . $_SESSION['player']->getName() . '
		</td>
		<td id="layout_map">
			<img src="images/';
// Add logic for the output of the correct map
$content .= 'map_' . $_SESSION['quest'] . '_';
// Determine their percentage done
$answered = $_SESSION[$_SESSION['quest']]->percentAnswered();
if ($answered < 33) $content .= '1';
elseif ($answered < 67) $content .= '2';
else $content .= '3';
$content .= '.jpg" alt="World Map" border="0" />
		</td>
	</tr>
</table>';

// Add the content to the page
$_SCRIPT['page']->setContent($content);
// Output the page
$_SCRIPT['page']->outputPage();
