<?php
/**
 * Question Presentation Page
 *
 * This is the main page of the game.  It gets the next unanswered question in
 * the specified QuestionList, and presents it to the user.  Of course, it 
 * puts the answers in a form that can be submitted to the file answer.php.  It
 * also outputs the player's score, avatar, name, and the progression of the maps.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * Every page must load the session so that everything works correctly
 */
include ('includes/session.php');

// Make sure that the user has a quest set up
if (!in_array($_SESSION['quest'], array('angelology', 'anthropology', 'hamartiology', 'inquisition'))) {
	header("Location: start.php");
	$_SESSION['feedback'] = '<p class="warn">You must start a Quest to answer a Trial</p>';
	exit();
} // end sending them to start if they have no quest

// We need to find the next unanswered question to output for this quest
$_SESSION['question'] = $_SESSION[$_SESSION['quest']]->nextUnanswered();

// Add the quest title
$content = '<p id="title"><img src="';
switch ($_SESSION['quest']) {
	case 'angelology':
		$content .= 'images/title_angelology.jpg';
		break;
	case 'anthropology':
		$content .= 'images/title_antropo.jpg';
		break;
	case 'hamartiology':
		$content .= 'images/title_sin.jpg';
		break;
	case 'inquisition':
		$content .= 'images/title_inquisition.jpg';
		break;
} // end addition of the correct title
$content .= "\" /></p>\r\n";

// Add some content
$content .= '<table cellpadding="0" cellspacing="0" id="layout_page">
	<tr>
		<td id="layout_graphic">
			<img src="' . $_SESSION['question']->getImage() . '" alt="Question Image" border="0" />
		</td>
		<td id="layout_question">';
// If this is not an inquisition, select a scenario to output
if ($_SESSION['quest'] != 'inquisition') {
	$key = array_rand($_SESSION['scenarios']);
	$content .= $_SESSION['scenarios'][$key];
	unset($key);
} // end output of scenario for non-inquisition
else {
	$content .= "<p>The Inquisitor gives you your next question:</p>";
} // end output of scenario for inquisition
$content .= $_SESSION['question']->getQuestion() . '
			<form action="answer.php" method="post" name="question">
				<fieldset>
					<legend>Answers</legend>' . "\r\n";
foreach ($_SESSION['question']->getAnswers() as $key=>$answer) {
	$content .= "\t\t\t\t\t" . '<div>
						<input type="radio" name="answer" id="answer' . $key . '" value="' . $key . '" />
						<label for="answer' . $key . '">' . $answer['answer'] . '</label>
					</div>
					' . "\r\n";
} // end adding each answer
$content .= "\t\t\t\t\t" . '<div>' . "\r\n";
// If it's an inquisition, give them a chance to say why
if ($_SESSION['quest'] == 'inquisition') {
	$content .= "\t\t\t\t\t<div>
						<label for=\"why\">Why?</label>
						<textarea name=\"why\" id=\"why\" rows=\"5\" cols\"40\"></textarea>
					</div>\r\n";
}// End addition of why question
$content .= "\t\t\t\t\t\t" . '<input type="submit" name="submit" id="submit" value="Answer This Trial" />
					</div>
				</fieldset>
			</form>
		</td>
	</tr>
	<tr>
		<td id="layout_score">
			' . $_SESSION['player']->toScore() . '
			<img src="' . $_SESSION['player']->getAvatar() . '" alt="" border="0" /><br />
			' . $_SESSION['player']->getName() . '
		</td>
		<td id="layout_map">
			<img src="images/';
// Add logic for the output of the correct map
$content .= 'map_' . $_SESSION['quest'] . '_';
// Determine their percentage done
$answered = $_SESSION[$_SESSION['quest']]->percentAnswered();
if ($answered < 33) $content .= '1';
elseif ($answered < 67) $content .= '2';
else $content .= '3';
$content .= '.jpg" alt="World Map" border="0" />
		</td>
	</tr>
</table>';

// Add the content to the page
$_SCRIPT['page']->setContent($content);
// Output the page
$_SCRIPT['page']->outputPage();
