<?php
/**
 * Question Add page
 *
 * This page allows the creators of the game to easily enter new questions into
 * the database.  It is not for the general public.  The question creator can
 * add the question text, indicate the quest, the difficulty, an image from the
 * bank, and any answers.  The number of answers is limited to 10 on this page, 
 * but the system can accept an infinite number of answers for any one question.
 * That wouldn't make a good game, though.
 * @package The_Theologian_Game
 * @author Andrew D. Goetz
 * @copyright  Andrew D. Goetz
 * @license http://creativecommons.org/licenses/by-sa/2.5/legalcode
 */

/**
 * Every page must load the session so that everything works correctly
 */
include ('includes/session.php');

// Add some content
$content = "<h1>Add a Question to the Database</h1>\r\n";
$content .= "<form action='question_add_process.php' method='post' name='question_add'>
	<fieldset>
		<div>
			<label for='question'>Question</label>
			<textarea name='question' id='question' rows='10' cols='40'></textarea>
		</div>
		<div>
			<label for='class'>Quest</label>
			<select name='class' id='class' size='1'>
				<option value='angelology'>Angelology</option>
				<option value='anthropology'>Anthropology</option>
				<option value='hamartiology'>Hamartiology</option>
				<option value='inquisition'>Inquisition</option>
			</select>
		</div>
		<div>
			<label for='difficulty'>Difficulty</label>
			<select name='difficulty' id='difficulty' size='1'>
				<option value='0'>Easy</option>
				<option value='1'>Medium</option>
				<option value='2'>Hard</option>
			</select>
		</div>
		<div>
			<label for='image'>Question Image</label>
			<select name='image' id='image' size='1'>\r\n";
// Find all of the currently available images
$dir = new DirectoryIterator("images");
foreach ($dir as $file) {
	if ($dir->isDot()) continue;
	$content .= "<option value='images/" . $file . "'>" . $file . "</option>\r\n";
} // end output of each file
$content .= "\t\t\t</select>
		</div>
	</fieldset>
	<fieldset>
		<legend>Answers</legend>
		<table cellpadding='0' cellspacing='0'>
			<thead>
				<tr>
					<th>
						Answer Text
					</th>
					<th>
						Correct?
					</th>
					<th>
						Order (integer)
					</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>
						<textarea name='answers[0][answer]' id='answers[0][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[0][is_correct]' id='answers[0][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[0][order]' id='answers[0][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[1][answer]' id='answers[1][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[1][is_correct]' id='answers[1][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[1][order]' id='answers[1][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[2][answer]' id='answers[2][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[2][is_correct]' id='answers[2][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[2][order]' id='answers[2][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[3][answer]' id='answers[3][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[3][is_correct]' id='answers[3][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[3][order]' id='answers[3][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[4][answer]' id='answers[4][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[4][is_correct]' id='answers[4][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[4][order]' id='answers[4][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[5][answer]' id='answers[5][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[5][is_correct]' id='answers[5][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[5][order]' id='answers[5][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[6][answer]' id='answers[6][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[6][is_correct]' id='answers[6][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[6][order]' id='answers[6][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[7][answer]' id='answers[7][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[7][is_correct]' id='answers[7][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[7][order]' id='answers[7][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[8][answer]' id='answers[8][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[8][is_correct]' id='answers[8][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[8][order]' id='answers[8][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[9][answer]' id='answers[9][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[9][is_correct]' id='answers[9][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[9][order]' id='answers[9][order]' size='2' value='0' />
					</td>
				</tr>
				<tr>
					<td>
						<textarea name='answers[10][answer]' id='answers[10][answer]' rows='3' cols='30'></textarea>
					</td>
					<td>
						<select name='answers[10][is_correct]' id='answers[10][is_correct]' size='1'>
							<option value='false' selected='selected'>No</option>
							<option value='true'>Yes</option>
						</select>
					</td>
					<td>
						<input type='text' name='answers[10][order]' id='answers[10][order]' size='2' value='0' />
					</td>
				</tr>
			</tbody>
		</table>
	</fieldset>
	<fieldset>
		<input type='submit' name='submit' value='Enter Question' />
	</fieldset>
</form>\r\n";

// Add the content to the page
$_SCRIPT['page']->setContent($content);
// Output the page
$_SCRIPT['page']->outputPage();


