-- Database Definition
--
-- This file gives the SQL definitions for the structure of the database of the
-- game.  It assumes that the installer has already created a database named
-- 'static_theologian', and connected to it.  This file will then create the
-- needed tables and insert the default scenario data.  The questions should be
-- enterd in a separate file.
-- @package The_Theologian_Game
-- @author Andrew D. Goetz
-- @copyright  Andrew D. Goetz
-- @license http://creativecommons.org/licenses/by-sa/2.5/legalcode

CREATE TABLE questions (
     id serial PRIMARY KEY,
     question text NOT NULL,
     class text NOT NULL DEFAULT 'angelology',
     difficulty int NOT NULL DEFAULT 0,
     image text,
     date_entered timestamp NOT NULL DEFAULT now()
);

CREATE TABLE answers (
     id serial PRIMARY KEY,
     question int NOT NULL REFERENCES questions(id),
     answer text NOT NULL,
     is_correct bool NOT NULL DEFAULT false,
     answer_order int NOT NULL DEFAULT 0,
     date_entered timestamp NOT NULL DEFAULT now()
);

CREATE TABLE scores (
     id serial PRIMARY KEY,
     name text NOT NULL,
     score int NOT NULL,
     avatar text NOT NULL,
     date_entered timestamp NOT NULL DEFAULT now()
);

CREATE TABLE scenarios (
	id int PRIMARY KEY,
	scenario text NOT NULL,
	date_entered timestamp NOT NULL DEFAULT now()
);

INSERT INTO scenarios (id, scenario) 
VALUES (1, '<p>As you walk along your path, you find come across a small village
	of picturesque thatched roof huts.  Deciding that this would be a good place
	to bed for the evening, you turn aside, to find the local inn.  You are 
	surprised to find that the streets seem deserted.  You know that the village
	has not been abandoned, because you see curtains pulled aside to see you
	walk down the main street.<p>
<p>Uncomfortable, but undaunted, you find the inn and step inside.  The woman 
	behind the counter looks at you with weary suspicion and a hint of surprise.</p>
<p>&ldquo;Do you know where you are?  I suspect not!  This town is under the 
	control of the evil heretic Pelagius!  We have tried to fight his deceptive
	ways, but we are no match for him.  If only we had paid attention in class!
	&rdquo;</p>
<p>&ldquo;I''m on a theological quest, maybe I can help?&rdquo; you answer.</p>
<p>&ldquo;You are!  We have refuted him at almost every turn, but there is one
	question at which he still confounds us.  If you can help us answer this
	question, we will be free of his evil power!</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (2, '<p>You have come to a crossroads, and do not know which way to turn.
	It is not on your map, and there are no signs to tell you which way to go.
	Confused and tired, you sit down to consider your options.  Just then, a
	fellow traveler comes up behind you.  He seems kind of shady, but he''s your
	only chance for help; so you ask him which way each path leads.</p>
<p>He considers you for a moment and offers to sell you a better map.  However,
	as a theology student, you know that you don''t have enough to purchase it 
	from him.  You offer, instead, to give him breif instruction in the art of
	theology.</p>
<p>&ldquo;Well,&rdquo; he says, &ldquo;I do have this question that I''ve always
	wondered about.  If you give me the correct answer, I''ll tell you which way
	is which</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (3, '<p>It is a beautiful day, and you are really starting to enjoy your 
	quest.  Suddenly, as if scripted, a mass of screaming, smelly, burning
	peasants run across your path.  You try to ask what is going on, but the only
	person who stopped long enough to talk to you just screams &ldquo;RUN!&rdquo;
	and takes off again.</p>
<p>You stand there confounded for a moment, and then decide that it must be a
	weird tradition in these parts and that you should carry on.  However, you
	then see a huge shadow rise to your right.  There he is, the great dragon: 
	Trogdor: The Burninator! There is no longer any time to run.  You must face 
	him.  He moves to step on you until he sees that you are on a theological
	quest.  He offers to let you continue on your quest if you can answer him
	one question:</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (4, '<p>The sun is starting to set, and you are ready for a rest from your
	travel for the evening.  However, there is no village or inn anywhere near.
	Looks like it will be another night under the stars with a rock for a 
	pillow.  It was good enough for Jacob. . . But then you see a glimmer down
	the road.  You walk a little further, and find a small cottage.  Screwing
	up your courage, you knock on the door and ask for shelter for the evening.
	A small, scared voice answers you from behind the door:</p>
<p>&ldquo;How do I know that you are truly on a theological quest?  How do I
	know that you are not a charlatan looking to rob me of what little I have?
	&rdquo; she asks.</p>
<p>&ldquo;I can prove it to you!  Just ask me a question.  I will answer it 
	faithfully and true.  I''m getting good at answering questions.  I seem to
	be doing it a lot now.&rdquo;</p>
<p>&ldquo;OK.  I''ll ask you the hardest theological question I know:&rdquo;</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (5, '<p>On the road, you are passed by an armed troupe and a couple of 
	horse drawn carriages.  Being a lowly theologian-wanna-be, you step aside, 
	allowing them to pass without trampling you.  As the carriage passes, you
	hear raised voices yelling at eachother.  Suddenly, someone from within yells
	&ldquo;STOP&rdquo;, and the caravan stops.  A rather portly man emerges
	from the carriage yelling: &ldquo;I won''t ride in the same carriage with 
	someone who believes that!&rdquo;  He starts to stomp away as the soldiers
	try to figure out who to guard.</p>
<p>A woman then comes out of the carriage with a frustrated &ldquo;Hurumph!&rdquo;
	After yelling something after her husband that you decide not to hear, she
	turns to you: &ldquo;What are you looking at?&rdquo;  You decide that a 
	frank and honest answer may not be wise as one of the soldier smiles 
	menacingly.</p>
<p>&ldquo;I''m just going about my theological quest,&rdquo; you say trying to
	look nonchalant.</p>
<p>She gets an exited look in her eye, and calls her husband back.  &ldquo;Here''s
	someone who can tell us once and for all what the answer is!&rdquo;  They 
	both decide to abide by your answer.  Don''t lead them astray!</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (6, '<p>It was a dark and stormy night, so you were wet and had stubbed 
	your toe more than once.  You notice a castle in the distance illuminated
	by the lightening.  You decide to make your way there.  After several minutes
	of stumbling in that general direction, you start to see the the light in
	the windows of the castle.  Finally, you arive at the castle door.  Knocking
	loudly, you ask for shelter.  There is no answer.  Great.  Suddenly, you 
	hear a scream in the distance.  Someone is in trouble, and it''s not you!</p>
<p>You drag your soaking body out from under the doorway just in time to see 
	a woman being dragged off into the woods next to the castle.  You race after
	her and her attacker.  As rush into the wood, her attacker confronts you.</p>
<p>&ldquo;She''s the only one who knows!  We must have the answer!  Please,
	we won''t hurt her.  We just need to know the answer to this question!</p>
<p>&ldquo;Ask me the question.  I''ll bet I can answer the question.  One condition,
	though.  You have to let her go!</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (7, '<p>Racing through the woods to try to get away from the savage
	bear, you run headlong into a knight guarding a bridge.</p>
<p>&ldquo;You may not pass!  Not unless you can answer me this question.&rdquo;<p>
<p>Relieved that you didn''t have to read a long scenario, you listen to his
	question:</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (8, '<p>As you look down into your half-eaten apple to find half a worm,
	you start to wonder about this quest on which you have embarked.  Is it
	really worth it to carry on?  Resigned to your quest, you get up and start
	down the path again.  You begin to notice scraps of parchment on the 
	ground.  they start to become more and more numerous, and you pick a few
	up.  They were too small to contain complete sentences, but they did seem
	to have random words written on them.  One of them reminded you of a question
	your Master Theolgian asked you before you began your quest:</p>');

INSERT INTO scenarios (id, scenario) 
VALUES (9, '<p>The Vikings you befriended went their way down the road, and you
	felt quite pleased that you were able to help them with their quest.  However,
	it had taken time away from your quest.  Realizing this, you decide to run
	along the road to try to make up some time.  As you moved to leap over some 
	small children who were playing in the road, one of them screamed and looked
	up at you.</p>
<p>&ldquo;I''m sorry sir,&rdquo; he says.  &ldquo;I thought you were the evil
	heretic Pelagius!  He has taken our parents captive in that cave over there.
	His followers keep confusing us with their weird theology, and we can''t 
	rescue our parents!&rdquo;</p>
<p>&ldquo;Don''t worry, youngling, I''m on a theology quest!  I''ll save them!&rdquo;
	You say while trying to look heroic.  You creep over to the cave to find it
	guarded by two rather menacing young men who seem to be speaking another 
	language.  You reveal yourself and challenge them to a Theology-off.</p>
<p>Finally, you receive the last question.  The fate of those poor people is 
	up to you!</p>');
	